'''
firebasin is a Python implementation of the Firebase API
'''

from .async import Firebase
